@@ -20,6 +20,18 @@ except NameError:
     # no bytes type in python < 2.6
     bytes = str
 
+def _safecast(a,b):
+    # check to see if array a can be safely cast
+    # to array b.  A little less picky than numpy.can_cast.
+    try:
+        is_safe = ((a == b) | (np.isnan(a) & np.isnan(b))).all()
+        #is_safe = np.allclose(a, b, equal_nan=True) # numpy 1.10.0
+    except:
+        try:
+            is_safe = (a == b).all() # string arrays.
+        except:
+            is_safe = False
+    return is_safe
 
 def _sortbylist(A,B):
     # sort one list (A) using the values from another list (B)
@@ -74,7 +86,7 @@ least_significant_digit=1, bits will be 4.
         return datout
 
 def _StartCountStride(elem, shape, dimensions=None, grp=None, datashape=None,\
-        put=False):
+        put=False, no_get_vars = True):
     """Return start, count, stride and indices needed to store/extract data
     into/from a netCDF variable.
 
@@ -122,12 +134,10 @@ def _StartCountStride(elem, shape, dimensions=None, grp=None, datashape=None,\
     sequences used to slice the netCDF Variable (Variable[elem]).
     shape : tuple containing the current shape of the netCDF variable.
     dimensions : sequence
-      The name of the dimensions. This is only useful to find out
-      whether or not some dimensions are unlimited. Only needed within
+      The name of the dimensions.
       __setitem__.
     grp  : netCDF Group
       The netCDF group to which the variable being set belongs to.
-      Only needed within __setitem__.
     datashape : sequence
       The shape of the data that is being stored. Only needed by __setitime__
     put : True|False (default False).  If called from __setitem__, put is True.
@@ -179,12 +189,19 @@ def _StartCountStride(elem, shape, dimensions=None, grp=None, datashape=None,\
                 elem.append(slice(None,None,None))
     else:   # Convert single index to sequence
         elem = [elem]
-
+    
+    hasEllipsis=False
+    for e in elem:
+        if type(e)==type(Ellipsis):
+            if hasEllipsis:
+                raise IndexError("At most one ellipsis allowed in a slicing expression")
+            hasEllipsis=True
     # replace boolean arrays with sequences of integers.
     newElem = []
     IndexErrorMsg=\
     "only integers, slices (`:`), ellipsis (`...`), and 1-d integer or boolean arrays are valid indices"
-    for i, e in enumerate(elem):
+    i=0
+    for e in elem:
         # string-like object try to cast to int
         # needs to be done first, since strings are iterable and
         # hard to distinguish from something castable to an iterable numpy array.
@@ -223,7 +240,7 @@ Boolean array must have the same shape as the data along this dimension."""
             # convert negative indices in 1d array to positive ones.
             ea = np.where(ea < 0, ea + shape[i], ea)
             if np.any(ea < 0):
-                raise IndexErro("integer index out of range")
+                raise IndexError("integer index out of range")
             # if unlim, let integer index be longer than current dimension
             # length.
             if ea.shape != (0,):
@@ -239,6 +256,24 @@ Boolean array must have the same shape as the data along this dimension."""
             newElem.append(e)
         # slice or ellipsis object
         elif type(e) == slice or type(e) == type(Ellipsis):
+            if no_get_vars and type(e) == slice and e.step not in [None,-1,1] and\
+               dimensions is not None and grp is not None:
+                # convert strided slice to integer sequence if possible
+                # (this will avoid nc_get_vars, which is slow - issue #680).
+                start = e.start if e.start is not None else 0
+                step = e.step
+                if e.stop is None and dimensions is not None and grp is not None:
+                    stop = len(_find_dim(grp, dimensions[i]))
+                else:
+                    stop = e.stop
+                    if stop < 0:
+                        stop = len(_find_dim(grp, dimensions[i])) + stop
+                try:
+                    ee = np.arange(start,stop,e.step)
+                    if len(ee) > 0:
+                        e = ee
+                except:
+                    pass
             newElem.append(e)
         else:  # castable to a scalar int, otherwise invalid
             try:
@@ -246,20 +281,20 @@ Boolean array must have the same shape as the data along this dimension."""
                 newElem.append(e)
             except:
                 raise IndexError(IndexErrorMsg)
+        if type(e)==type(Ellipsis): 
+            i+=1+nDims-len(elem)
+        else:
+            i+=1
     elem = newElem
 
     # replace Ellipsis and integer arrays with slice objects, if possible.
-    hasEllipsis = False
     newElem = []
     for e in elem:
         ea = np.asarray(e)
         # Replace ellipsis with slices.
         if type(e) == type(Ellipsis):
-            if hasEllipsis:
-                raise IndexError("At most one ellipsis allowed in a slicing expression")
             # The ellipsis stands for the missing dimensions.
             newElem.extend((slice(None, None, None),) * (nDims - len(elem) + 1))
-            hasEllipsis = True
         # Replace sequence of indices with slice object if possible.
         elif np.iterable(e) and len(e) > 1:
             start = e[0]
@@ -269,8 +304,13 @@ Boolean array must have the same shape as the data along this dimension."""
                 ee = range(start,stop,step)
             except ValueError: # start, stop or step is not valid for a range
                 ee = False
-            if ee and len(e) == len(ee) and (e == np.arange(start,stop,step)).all():
-                newElem.append(slice(start,stop,step))
+            if no_get_vars and ee and len(e) == len(ee) and (e == np.arange(start,stop,step)).all():
+                # don't convert to slice unless abs(stride) == 1
+                # (nc_get_vars is very slow, issue #680)
+                if step not in [1,-1]:
+                    newElem.append(e)
+                else:
+                    newElem.append(slice(start,stop,step))
             else:
                 newElem.append(e)
         elif np.iterable(e) and len(e) == 1:
@@ -683,7 +723,7 @@ def _nc3tonc4(filename3,filename4,unpackshort=True,
         ncvar = ncfile3.variables[varname]
         if not quiet: sys.stdout.write('copying variable %s\n' % varname)
         # quantize data?
-        if lsd_dict is not None and lsd_dict.has_key(varname):
+        if lsd_dict is not None and varname in lsd_dict:
             lsd = lsd_dict[varname]
             if not quiet: sys.stdout.write('truncating to least_significant_digit = %d\n'%lsd)
         else:
