@@ -1,5 +1,6 @@
-import glob, os, sys, unittest, netCDF4
+import glob, os, sys, unittest
 from netCDF4 import getlibversion,__hdf5libversion__,__netcdf4libversion__,__version__
+from netCDF4 import __has_cdf5_format__, __has_nc_inq_path__, __has_nc_par__
 
 # can also just run
 # python -m unittest discover . 'tst*py'
@@ -14,13 +15,13 @@ if python3:
 else:
     test_files.remove('tst_unicode3.py')
     sys.stdout.write('not running tst_unicode3.py ...\n')
-if __netcdf4libversion__ < '4.2.1':
+if __netcdf4libversion__ < '4.2.1' or __has_nc_par__:
     test_files.remove('tst_diskless.py')
     sys.stdout.write('not running tst_diskless.py ...\n')
-if __netcdf4libversion__ < '4.1.2':
+if not __has_nc_inq_path__:
     test_files.remove('tst_filepath.py')
     sys.stdout.write('not running tst_filepath.py ...\n')
-if __netcdf4libversion__ < '4.4.0' or sys.maxsize < 2**32:
+if not __has_cdf5_format__:
     test_files.remove('tst_cdf5.py')
     sys.stdout.write('not running tst_cdf5.py ...\n')
 
@@ -41,12 +42,13 @@ def test(verbosity=1):
     runner.run(testsuite)
 
 if __name__ == '__main__':
-    import numpy
+    import numpy, cython
     sys.stdout.write('\n')
     sys.stdout.write('netcdf4-python version: %s\n' % __version__)
     sys.stdout.write('HDF5 lib version:       %s\n' % __hdf5libversion__)
     sys.stdout.write('netcdf lib version:     %s\n' % __netcdf4libversion__)
     sys.stdout.write('numpy version           %s\n' % numpy.__version__)
+    sys.stdout.write('cython version          %s\n' % cython.__version__)
     runner = unittest.TextTestRunner(verbosity=1)
     result = runner.run(testsuite)
     if not result.wasSuccessful():
