@@ -1,7 +1,7 @@
 from netcdftime import utime, JulianDayFromDate, DateFromJulianDay
 from netcdftime import datetime as datetimex
 from netcdftime import DatetimeNoLeap, DatetimeAllLeap, Datetime360Day, DatetimeJulian, \
-    DatetimeGregorian, DatetimeProlepticGregorian
+    DatetimeGregorian, DatetimeProlepticGregorian, _parse_date
 from netCDF4 import Dataset, num2date, date2num, date2index, num2date
 import copy
 import numpy
@@ -226,9 +226,9 @@ class netcdftimeTestCase(unittest.TestCase):
         # check timezone offset
         d = datetime(2012, 2, 29, 15)
         # mixed_tz is -6 hours from UTC, mixed is UTC so
-        # difference in elapsed time is 6 hours.
+        # difference in elapsed time is -6 hours.
         assert(self.cdftime_mixed_tz.date2num(
-            d) - self.cdftime_mixed.date2num(d) == 6)
+            d) - self.cdftime_mixed.date2num(d) == -6)
 
         # Check comparisons with Python datetime types
 
@@ -391,15 +391,15 @@ class netcdftimeTestCase(unittest.TestCase):
         # date after gregorian switch, python datetime used
         date = datetime(1682,10,15) # assumed UTC
         num = date2num(date,units)
-        # UTC is 7 hours ahead of units, so num should be 7
-        assert (num == 7)
+        # UTC is 7 hours ahead of units, so num should be -7
+        assert (num == -7)
         assert (num2date(num, units) == date)
         units = 'hours since 1482-10-15 -07:00 UTC'
         # date before gregorian switch, netcdftime datetime used
         date = datetime(1482,10,15)
         num = date2num(date,units)
         date2 = num2date(num, units)
-        assert (num == 7)
+        assert (num == -7)
         assert (date2.year == date.year)
         assert (date2.month == date.month)
         assert (date2.day == date.day)
@@ -476,6 +476,35 @@ class netcdftimeTestCase(unittest.TestCase):
         assert (d.month == 1)
         assert (d.day == 1)
         assert (d.hour == 0)
+        # test fix for issue #659 (proper treatment of negative time values).
+        units = 'days since 1800-01-01 00:00:0.0'
+        d = num2date(-657073, units, calendar='standard')
+        assert (d.year == 1)
+        assert (d.month == 1)
+        assert (d.day == 1)
+        assert (d.hour == 0)
+        # issue 685: wrong time zone conversion
+        # 'The following times all refer to the same moment: "18:30Z", "22:30+04", "1130-0700", and "15:00-03:30'
+        # (https://en.wikipedia.org/w/index.php?title=ISO_8601&oldid=787811367#Time_offsets_from_UTC)
+        # test num2date
+        utc_date = datetime(2000,1,1,18,30)
+        for units in ("hours since 2000-01-01 22:30+04:00", "hours since 2000-01-01 11:30-07:00", "hours since 2000-01-01 15:00-03:30"):
+            d = num2date(0, units, calendar="standard")
+            assert(numpy.abs((d-utc_date).total_seconds()) < 1.e-3)
+            # also test with negative values to cover 2nd code path
+            d = num2date(-1, units, calendar="standard")
+            assert(numpy.abs((d - \
+                (utc_date-timedelta(hours=1))).total_seconds()) < 1.e-3)
+
+            n = date2num(utc_date, units, calendar="standard")
+            # n should always be 0 as all units refer to the same point in time
+            self.assertEqual(n, 0)
+        # explicitly test 2nd code path for date2num
+        units = "hours since 2000-01-01 22:30+04:00"
+        n = date2num(utc_date, units, calendar="julian")
+        # n should always be 0 as all units refer to the same point in time
+        assert_almost_equal(n, 0)
+
 
 
 class TestDate2index(unittest.TestCase):
@@ -924,5 +953,40 @@ class DateTime(unittest.TestCase):
         for func in [not_comparable_1, not_comparable_2, not_comparable_3, not_comparable_4]:
             self.assertRaises(TypeError, func)
 
+class issue17TestCase(unittest.TestCase):
+    """Regression tests for issue #17/#669."""
+    # issue 17 / 699: timezone formats not supported correctly
+    # valid timezone formats are: +-hh, +-hh:mm, +-hhmm
+
+    def setUp(self):
+        pass
+
+    def test_parse_date_tz(self):
+        "Test timezone parsing in _parse_date"
+
+        # these should succeed and are ISO8601 compliant
+        expected_parsed_date = (2017, 5, 1, 0, 0, 0, 60.0)
+        for datestr in ("2017-05-01 00:00+01:00", "2017-05-01 00:00+0100", "2017-05-01 00:00+01"):
+            d = _parse_date(datestr)
+            assert_equal(d, expected_parsed_date)
+        # some more tests with non-zero minutes, should all be ISO compliant and work
+        expected_parsed_date = (2017, 5, 1, 0, 0, 0, 85.0)
+        for datestr in ("2017-05-01 00:00+01:25", "2017-05-01 00:00+0125"):
+            d = _parse_date(datestr)
+            assert_equal(d, expected_parsed_date)
+        # these are NOT ISO8601 compliant and should not even be parseable but will be parsed with timezone anyway
+        # because, due to support of other legacy time formats, they are difficult to reject
+        # ATTENTION: only the hours part of this will be parsed, single-digit minutes will be ignored!
+        expected_parsed_date = (2017, 5, 1, 0, 0, 0, 60.0)
+        for datestr in ("2017-05-01 00:00+01:0", "2017-05-01 00:00+01:", "2017-05-01 00:00+01:5"):
+            d = _parse_date(datestr)
+            assert_equal(d, expected_parsed_date)
+        # these should not even be parseable as datestrings but are parseable anyway with ignored timezone
+        # this is because the module also supports some legacy, non-standard time strings
+        expected_parsed_date = (2017, 5, 1, 0, 0, 0, 0.0)
+        for datestr in ("2017-05-01 00:00+1",):
+            d = _parse_date(datestr)
+            assert_equal(d, expected_parsed_date)
+
 if __name__ == '__main__':
     unittest.main()
