@@ -61,7 +61,10 @@ class TestgetStartCountStride(unittest.TestCase):
         # this one should be converted to a slice
         elem = [slice(None), [1,3,5], 8]
         start, count, stride, put_ind = _StartCountStride(elem, (50, 6, 10))
-        assert_equal(put_ind[...,1].squeeze(), slice(None,None,None))
+        # pull request #683 now does not convert integer sequences to strided
+        # slices.
+        #assert_equal(put_ind[...,1].squeeze(), slice(None,None,None))
+        assert_equal(put_ind[...,1].squeeze(), [0,1,2])
 
 
     def test_multiple_sequences(self):
@@ -181,7 +184,33 @@ class TestgetStartCountStride(unittest.TestCase):
         assert_equal(count, 0)
         assert_equal(_out_array_shape(count), (0,))
 
+    def test_ellipsis(self):
+        elem=(Ellipsis, slice(1, 4))
+        start, count, stride, put_ind = _StartCountStride(elem, (22,25,4))
+        assert_equal(start[0,0,0], [0, 0, 1])
+        assert_equal(count[0,0,0], (22, 25, 3))
+        assert_equal(put_ind[0,0,0], (slice(None), slice(None), slice(None)))
 
+        elem=(Ellipsis, [15,16,17,18,19], slice(None), slice(None))
+        start, count, stride, put_ind = _StartCountStride(elem, (2,10,20,10,10))
+        assert_equal(start[0,0,0,0,0], [0, 0, 15, 0, 0])
+        assert_equal(count[0,0,0,0,0], (2, 10, 5, 10, 10))
+        assert_equal(put_ind[0,0,0,0,0], (slice(None), slice(None), slice(None), slice(None), slice(None)))
+        
+        try:
+            elem=(Ellipsis, [15,16,17,18,19], slice(None))
+            start, count, stride, put_ind = _StartCountStride(elem, (2,10,20,10,10))
+            assert_equal(None, 'Should throw an exception')
+        except IndexError as e:
+            assert_equal(str(e), "integer index exceeds dimension size")
+            
+        try:
+            elem=(Ellipsis, [15,16,17,18,19], Ellipsis)
+            start, count, stride, put_ind = _StartCountStride(elem, (2,10, 20,10,10))
+            assert_equal(None, 'Should throw an exception')
+        except IndexError as e:
+            assert_equal(str(e), "At most one ellipsis allowed in a slicing expression")
+            
 class TestsetStartCountStride(unittest.TestCase):
 
     def test_basic(self):
@@ -189,7 +218,7 @@ class TestsetStartCountStride(unittest.TestCase):
         grp = FakeGroup({'x':False, 'y':False, 'time':True})
 
         elem=(slice(None), slice(None), 1)
-        start, count, stride, take_ind = _StartCountStride(elem, (22, 25, 1), ['x', 'y', 'time'], grp, (22,25))
+        start, count, stride, take_ind = _StartCountStride(elem, (22, 25, 1), ['x', 'y', 'time'], grp, (22,25), put=True)
         assert_equal(start[0][0][0], [0, 0, 1])
         assert_equal(count[0][0][0], (22, 25, 1))
         assert_equal(take_ind[0][0][0], (slice(None), slice(None), -1))
@@ -205,7 +234,7 @@ class TestsetStartCountStride(unittest.TestCase):
         grp = FakeGroup({'x':False, 'y':False})
 
         elem=([0,4,5], slice(20, None))
-        start, count, stride, take_ind = _StartCountStride(elem, (22, 25), ['x', 'y'], grp, (3,5))
+        start, count, stride, take_ind = _StartCountStride(elem, (22, 25), ['x', 'y'], grp, (3,5), put=True)
         assert_equal(start[0][0], (0, 20))
         assert_equal(start[1][0], (4, 20))
         assert_equal(start[2][0], (5, 20))
@@ -215,12 +244,11 @@ class TestsetStartCountStride(unittest.TestCase):
         assert_equal(take_ind[1][0], (1, slice(None)))
         assert_equal(take_ind[2][0], (2, slice(None)))
 
-
     def test_booleans(self):
         grp = FakeGroup({'x':False, 'y':False, 'z':False})
 
         elem=([0,4,5], np.array([False, True, False, True, True]), slice(None))
-        start, count, stride, take_ind = _StartCountStride(elem, (10, 5, 12), ['x', 'y', 'z'], grp, (3, 3, 12))
+        start, count, stride, take_ind = _StartCountStride(elem, (10, 5, 12), ['x', 'y', 'z'], grp, (3, 3, 12), put=True)
         assert_equal(start[0][0][0], (0, 1, 0))
         assert_equal(start[1][0][0], (4, 1, 0))
         assert_equal(start[2][0][0], (5, 1, 0))
@@ -244,15 +272,52 @@ class TestsetStartCountStride(unittest.TestCase):
         assert_equal(take_ind[2][0][0], (2, slice(None), slice(None)))
 
 
-        elem = (slice(None, None, 2), slice(None), slice(None))
-        start, count, stride, take_ind = _StartCountStride(elem, (0, 6, 7),\
-                ['time', 'x', 'y'], grp, (10, 6, 7),put=True)
-        assert_equal(start[0][0][0], (0,0,0))
-        assert_equal(count[0][0][0], (5, 6, 7))
-        assert_equal(stride[0][0][0], (2, 1, 1))
-        assert_equal(take_ind[0][0][0], 3*(slice(None),))
+        # pull request #683 broke this, since _StartCountStride now uses
+        # Dimension.__len__.
+        #elem = (slice(None, None, 2), slice(None), slice(None))
+        #start, count, stride, take_ind = _StartCountStride(elem, (0, 6, 7),\
+        #        ['time', 'x', 'y'], grp, (10, 6, 7),put=True)
+        #assert_equal(start[0][0][0], (0,0,0))
+        #assert_equal(count[0][0][0], (5, 6, 7))
+        #assert_equal(stride[0][0][0], (2, 1, 1))
+        #assert_equal(take_ind[0][0][0], 3*(slice(None),))
+     
+    def test_ellipsis(self):
+        grp = FakeGroup({'x':False, 'y':False, 'time':True})
 
+        elem=(Ellipsis, slice(1, 4))
+        start, count, stride, take_ind = _StartCountStride(elem, (22,25,1),\
+            ['x', 'y', 'time'], grp, (22,25,3), put=True)
+        assert_equal(start[0,0,0], [0, 0, 1])
+        assert_equal(count[0,0,0], (22, 25, 3))
+        assert_equal(take_ind[0,0,0], (slice(None), slice(None), slice(None)))
+        
+        grp = FakeGroup({'time':True, 'h':False, 'z':False, 'y':False, 'x':False})
 
+        elem=(Ellipsis, [15,16,17,18,19], slice(None), slice(None))
+        start, count, stride, take_ind = _StartCountStride(elem, (2,10,20,10,10),\
+            ['time', 'h', 'z', 'y', 'x'], grp, (2,10,5,10,10), put=True)
+        assert_equal(start[0,0,0,0,0], [0, 0, 15, 0, 0])
+        assert_equal(count[0,0,0,0,0], [2, 10, 5, 10, 10])
+        assert_equal(stride[0,0,0,0,0], [1, 1, 1, 1, 1])
+        assert_equal(take_ind[0,0,0,0,0], (slice(None), slice(None), slice(None), slice(None), slice(None)))
+        
+        try:
+            elem=(Ellipsis, [15,16,17,18,19], slice(None))
+            start, count, stride, take_ind = _StartCountStride(elem, (2,10,20,10,10),\
+               ['time', 'z', 'y', 'x'], grp, (2,10,5,10,10), put=True)
+            assert_equal(None, 'Should throw an exception')
+        except IndexError as e:
+            assert_equal(str(e), "integer index exceeds dimension size")
+            
+        try:
+            elem=(Ellipsis, [15,16,17,18,19], Ellipsis)
+            start, count, stride, take_ind = _StartCountStride(elem, (2,10, 20,10,10),\
+               ['time', 'z', 'y', 'x'], grp, (2,10,5,10,10), put=True)
+            assert_equal(None, 'Should throw an exception')
+        except IndexError as e:
+            assert_equal(str(e), "At most one ellipsis allowed in a slicing expression")
+       
 class FakeGroup(object):
     """Create a fake group instance by passing a dictionary of booleans
     keyed by dimension name."""
